
"""
_________________________________________________________________________________________
ScreenPoint refers to a point in the screen. All the recorded points are generated here.
You may use these objects and its methods to quickly create an automation script.
_________________________________________________________________________________________
"""

from pyautoeasy import ScreenPoint

sd = ScreenPoint(pos=(1140, 669))
sd.click_here()


asd = ScreenPoint(pos=(1089, 230))
asd.click_here()




from pyautoeasy.screen_point import ScreenPoint


minimise = ScreenPoint(pos=(1835, 47))
minimise.click_here()


searchbar = ScreenPoint(pos=(220, 151))
searchbar.click_here()
searchbar.type_here("iron man photos")


images = ScreenPoint(pos=(277, 207))
images.click_here()


firstphoto = ScreenPoint(pos=(82, 393))
firstphoto.right_click_here()


save_image = ScreenPoint(pos=(218, 637))
save_image.click_here()


save_button = ScreenPoint(pos=(1530, 105))
save_button.click_here()




import json
from queue import Queue

import pyautogui
from pynput import keyboard
import os

DOC_STRING_FOR_GENERATED_PROGRAM = '''
\"\"\"
_________________________________________________________________________________________
ScreenPoint refers to a point in the screen. All the recorded points are generated here.
You may use these objects and its methods to quickly create an automation script.
_________________________________________________________________________________________
\"\"\"
'''

MODIFIER_KEYS_LINUX = {
    'ctrl': 'Key.ctrl',
    'alt': 'Key.alt',
    'cmd': 'Key.cmd',
}


MODIFIER_KEYS_WINDOWS = {
    'ctrl': 'Key.ctrl_l',
    'alt': 'Key.alt_l',
}
if os.name == 'nt': #windows machine
    MODIFIER_KEYS = MODIFIER_KEYS_WINDOWS
else:
    MODIFIER_KEYS = MODIFIER_KEYS_LINUX

message_queue = Queue()
QUEUE_POLLING_INTERVAL = 0.5

class InteractivePositionLocator:
    """
    Interactive tool to grab the x,y positions of desired locations in the screen.
    Assign variable names to these positions and generate a sample.py program.
    """
    KEY_COMBINATION_SAVE = {'Key.alt', 's'}
    KEY_COMBINATION_RECORD_CURSOR = {'Key.alt', 'r'}

    def __init__(self, output_file, save_key='alt+s', cursor_record_key='alt+r'):
        self.saved_cursor_positions = {}

        # The currently active modifiers
        self.pressed_keys = set()
        self.output_file = output_file if output_file.endswith('.py') else output_file + '.py'

        self.KEY_COMBINATION_SAVE = self.get_keys(save_key)
        self.KEY_COMBINATION_RECORD_CURSOR = self.get_keys(cursor_record_key)
        self.stop_listener = False

    def record_cursor_pos(self):
        x, y = pyautogui.position()
        position_variable_name = pyautogui.prompt(
            f'Recording cursor position ({x},{y}).\n Give a name to refer to this position:')
        if position_variable_name:
            self.saved_cursor_positions[position_variable_name] = (x, y)
            print(f'\nRecording Cursor Position at ({x},{y}) as variable {position_variable_name}')

    def on_press(self, key):
        key = str(key).strip("'")
        self.pressed_keys.add(key)
        if self.KEY_COMBINATION_SAVE.issubset(self.pressed_keys):
            message_queue.put(None)
        elif self.KEY_COMBINATION_RECORD_CURSOR.issubset(self.pressed_keys):
            message_queue.put(key)

    def on_release(self, key):
        key = str(key).strip("'")
        if key in self.pressed_keys:
            self.pressed_keys.remove(key)

    def generate_program(self):
        sample_program_file_name = self.output_file
        print(f'\nGenerating sample automation program : {sample_program_file_name}')

        program_lines = []
        program_lines.append(DOC_STRING_FOR_GENERATED_PROGRAM)
        program_lines.append('from pyautoeasy import ScreenPoint\n')
        for variable_name, pos in self.saved_cursor_positions.items():
            program_lines.append(f'{variable_name} = ScreenPoint(pos={pos})')
            program_lines.append(f'{variable_name}.click_here()')
            program_lines.append('\n')

        program = '\n'.join(program_lines)
        with open(sample_program_file_name, 'w') as file:
            file.write(program)

    def grab_cursor_positions(self):
        """
        Start interactive program to grab the cursor positions.
        :return:
        """
        keyboard_listeners = keyboard.Listener(on_press=self.on_press, on_release=self.on_release)
        keyboard_listeners.start()

        while True:
            data = message_queue.get()
            if not data:
                print('Stopping Keyboard and mouse listeners..')
                keyboard_listeners.stop()
                break
            self.record_cursor_pos()

        print(f'Saving the following cursor positions : {self.saved_cursor_positions} to cursor_positions.json')
        with open('cursor_positions.json', 'w') as convert_file:
            convert_file.write(json.dumps(self.saved_cursor_positions))

        self.generate_program()

    def get_keys(self, key_combination):
        keys = set()
        key_combination = key_combination.strip().split('+')
        for key in key_combination:
            if key in MODIFIER_KEYS:
                keys.add(MODIFIER_KEYS[key])
            else:
                keys.add(key)
        return keys


if __name__ == '__main__':
    locator = InteractivePositionLocator(output_file='sample', save_key='alt+s', cursor_record_key='alt+r')
    locator.grab_cursor_positions()



import pyautogui
import time

class ScreenPoint:
    """
    ScreenPoint refers to a point in the screen. All the recorded points are generated here.
    You may use these objects and its methods to quickly create an automation script.
    """

    class Config:
        """Global Configurations for ScreenPoint objects"""
        delay = 1 # each command will be executed after this much delay, unless overidden by the arg ``after_sleeping_for``

    def __init__(self, pos):
        self.pos = pos

    def cursor_here(self, after_sleeping_for=Config.delay):
        """
        move the cursor to this point.
        :param after_sleeping_for: sleep for these many seconds before doing the operation.
        :return:
        """
        time.sleep(after_sleeping_for)
        pyautogui.moveTo(self.pos[0], self.pos[1])

    def click_here(self, after_sleeping_for=Config.delay, num_of_clicks=1):
        """
        left click on this point.
        :param after_sleeping_for: sleep for these many seconds before doing the operation.
        :param num_of_clicks: the number of clicks
        :return:
        """
        time.sleep(after_sleeping_for)
        pyautogui.click(x=self.pos[0], y=self.pos[1], clicks=num_of_clicks)

    def double_click_here(self, after_sleeping_for=Config.delay):
        """
        double click on this point.
        :param after_sleeping_for: sleep for these many seconds before doing the operation.
        :return:
        """
        self.click_here(after_sleeping_for=after_sleeping_for, num_of_clicks=2)

    def triple_click_here(self, after_sleeping_for=Config.delay):
        """
        triple click on this point. useful for selecting the text on the line.
        :param after_sleeping_for: sleep for these many seconds before doing the operation.
        :return:
        """
        self.click_here(after_sleeping_for=after_sleeping_for, num_of_clicks=3)

    def right_click_here(self, after_sleeping_for=Config.delay):
        """
        right click on this point.
        :param after_sleeping_for: sleep for these many seconds before doing the operation.
        :return:
        """
        time.sleep(after_sleeping_for)
        pyautogui.click(x=self.pos[0], y=self.pos[1], button='RIGHT')

    def type_here(self, text, enter=True, after_sleeping_for=Config.delay):
        """
        type text using keyboard
        :param text: the text to type
        :param enter: if True, an ENTER key will be pressed after typing the text
        :param after_sleeping_for: sleep for these many seconds before doing the operation.
        :return:
        """
        self.cursor_here(after_sleeping_for=0)
        time.sleep(after_sleeping_for)
        pyautogui.write(text)
        if enter:
            pyautogui.press('enter')


import argparse

from tabulate import tabulate

from pyautoeasy import InteractivePositionLocator


def get_args():
    main_parser = argparse.ArgumentParser(prog='pyautoeasy', usage='%(prog)s --locate --output sample')
    main_parser.add_argument('-o', '--output', default='sample', help='File name of the generated sample program')
    main_parser.add_argument('--cursor-record-key', default='alt+r',
                             help='Records the current position of cursor and prompts for a meaningful name for this location.')
    main_parser.add_argument('--save-key', default='alt+s',
                             help='saves the recorded cursor positions and generates a sample program')
    args = main_parser.parse_args()
    return args


def display_intro(args):
    text = f"""
        Running Interactive pyautoeasy...
        
    Press {args.cursor_record_key} to record a cursor position 
    Press {args.save_key} to save and generate sample program 
    """
    table = [[text]]
    output = tabulate(table, tablefmt='grid')
    print(output)


def main():
    args = get_args()
    display_intro(args)
    locator = InteractivePositionLocator(output_file=args.output, save_key=args.save_key,
                                         cursor_record_key=args.cursor_record_key)
    locator.grab_cursor_positions()

if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.5'
DESCRIPTION = 'A simple GUI automation tool to automate your boring tasks'

# Setting up
setup(
    name="pyautoeasy",
    version=VERSION,
    author="Dingu Sagar",
    author_email="<dingusagar@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=[
        'PyAutoGUI==0.9.53',
        'pynput==1.7.3',
        'tabulate==0.8.9'
    ],
    keywords=['python', 'pyautoeasy', 'pyautogui', 'automate gui', 'automate ui', 'ui automation'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    entry_points={
        'console_scripts': ['pyautoeasy=pyautoeasy.cli:main'],
    }
)
